smartcard.pyro.PyroReader.PyroReader

# ``smartcard`.`pyro`.`PyroReader`.`PyroReader``

class documentation

`class PyroReader(Reader):`

View In Hierarchy

Remote reader class.

Class | `Factory` | Undocumented
Static Method | `readers` | Undocumented
Method | `__init__` | Constructs a new Remote Reader client implementation from a Pyro URI.
Method | `addtoreadergroup` | Add reader to a reader group.
Method | `createConnection` | Return a card connection thru a remote reader.
Method | `removefromreadergroup` | Remove a reader from a reader group
Instance Variable | `name` | Undocumented
Instance Variable | `reader` | Undocumented
Instance Variable | `uri` | Undocumented

Inherited from `Reader`:

Method | `__eq__` | Returns True if self==other (same name).
Method | `__hash__` | Returns a hash value for this object (self.name is unique).
Method | `__repr__` | Returns card reader name string for `object` calls.
Method | `__str__` | Returns card reader name string for str(object) calls.

def readers(groups=[]):

Undocumented

def __init__(self, readername):
overrides `smartcard.reader.Reader.Reader.__init__`

Constructs a new Remote Reader client implementation from a Pyro URI.

def addtoreadergroup(self, groupname):
overrides `smartcard.reader.Reader.Reader.addtoreadergroup`

Add reader to a reader group.

def createConnection(self):
overrides `smartcard.reader.Reader.Reader.createConnection`

Return a card connection thru a remote reader.

def removefromreadergroup(self, groupname):
overrides `smartcard.reader.Reader.Reader.removefromreadergroup`

Remove a reader from a reader group

name =
overrides `smartcard.reader.Reader.Reader.name`

Undocumented

reader =

Undocumented

uri =

Undocumented